/*
 * JScroll - the scrollable desktop pane for Java.
 * Copyright (C) 2003 Tom Tessier
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

import org.jscroll.JScrollDesktopPane;

import javax.swing.*;

import java.awt.event.*;


/**
 * This class provides a more complex example of the scrollable desktop.
 *
 * To compile against scrollabledesktop.jar:
 *
 *  javac -classpath scrollabledesktop.jar TestDesktop.java
 *
 * To execute against scrollabledesktop.jar:
 *
 *  java -classpath .;scrollabledesktop.jar TestDesktop
 *
 * Note that if scrollabledesktop.jar is added to the global classpath
 *  via the CLASSPATH environment variable, the -classpath attribute
 *  is unnecessary
 *
 */
public class TestDesktop {
    private JScrollDesktopPane jscrollDesktop;
    private JInternalFrame oldFrame;
    private JInternalFrame newFrame;
    private int counter = 1;

    /**
     * Creates a new TestDesktop object.
     */
    public TestDesktop() {
        // use system look and feel
        try {
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        } catch (Exception e) {
        }
        JFrame f = new JFrame("Test Desktop");

        // create the scrollable desktop instance and add it to the JFrame
        jscrollDesktop = new JScrollDesktopPane();

        f.getContentPane().add(jscrollDesktop);

        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit()
                                                        .getScreenSize();
        f.setBounds(50, 50, screenSize.width - (50 * 2),
            screenSize.height - (50 * 2));
        f.addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                    System.exit(0);
                }
            });

        // prepare the menuBar
        JMenuBar menuBar = createMenuBar();
        f.setJMenuBar(menuBar);

        // register the menu bar with the scrollable desktop
        jscrollDesktop.registerMenuBar(menuBar);

        // register the default internal frame icon
        jscrollDesktop.registerDefaultFrameIcon(new ImageIcon("images/frmeicon.gif"));

        f.setVisible(true);

        // example of letting the scrollable desktop build and add the frame
        oldFrame = jscrollDesktop.add("Frame " + counter++, new FrameContents());

        // example of manually building and adding a frame
        JInternalFrame manuallyBuiltFrame = new JInternalFrame("Manually Built");
        manuallyBuiltFrame.getContentPane().add(new FrameContents());
        manuallyBuiltFrame.pack();
        manuallyBuiltFrame.setVisible(true);
        jscrollDesktop.add(manuallyBuiltFrame);

        // save in newFrame for later adjustment by the menu below
        newFrame = manuallyBuiltFrame;
    }

    /**
     * creates the menu bar for this sample application
     *
     * @return the JMenuBar
     */
    private JMenuBar createMenuBar() {
        JMenuBar menuBar = new JMenuBar();

        JMenu menu = new JMenu("File");
        menu.setMnemonic(KeyEvent.VK_F);

        JMenuItem menuItem = new JMenuItem("New frame");
        menuItem.setMnemonic(KeyEvent.VK_N);
        menuItem.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    // add a new window, its contents the FrameContents class
                    oldFrame = newFrame;
                    newFrame = jscrollDesktop.add("Frame " + counter++, new FrameContents());
                }
            });

        menu.add(menuItem);

        menuItem = new JMenuItem("Select last frame");
        menuItem.setMnemonic(KeyEvent.VK_S);
        menuItem.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    if (oldFrame != null) {
                        jscrollDesktop.setSelectedFrame(oldFrame);
                    }
                }
            });

        menu.add(menuItem);

        menuItem = new JMenuItem("Flag contents changed, last frame");
        menuItem.setMnemonic(KeyEvent.VK_F);
        menuItem.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    if (oldFrame != null) {
                        jscrollDesktop.flagContentsChanged(oldFrame);
                    }
                }
            });

        menu.add(menuItem);

        menuItem = new JMenuItem("Close current frame");
        menuItem.setMnemonic(KeyEvent.VK_C);
        menuItem.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    JInternalFrame f = jscrollDesktop.getSelectedFrame();

                    if (f != null) {
                        jscrollDesktop.remove(f);
                    }
                }
            });

        menu.add(menuItem);
        menu.addSeparator();

        menuItem = new JMenuItem("Exit");
        menuItem.setMnemonic(KeyEvent.VK_X);
        menuItem.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    System.exit(0);
                }
            });
        menu.add(menuItem);

        menuBar.add(menu);

        return menuBar;
    }

    /**
     * starts up the test destop
     *
     * @param arg the command line arguments
     */
    public static void main(String[] arg) {
        new TestDesktop();
    }
}
